
# q-expansion of newform 250.3.f.b, downloaded from the LMFDB on 03 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 250
weight = 3
poly_data = [16, 0, 6560, 0, 15196, 0, 14480, 0, 7341, 0, 2130, 0, 351, 0, 30, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[6528, -95008, 1294616, -589924, 2403480, -840674, 1726068, -514181, 614968, -158776, 114532, -25551, 10504, -2016, 364, -61], 5728], [[6528, 95008, 1294616, 589924, 2403480, 840674, 1726068, 514181, 614968, 158776, 114532, 25551, 10504, 2016, 364, 61], 5728], [[-3040, 38168, 986600, 994584, 2066448, 1778096, 1683462, 1279041, 681348, 463786, 143378, 88651, 14644, 8366, 550, 297], 5728], [[-3040, -38168, 986600, -994584, 2066448, -1778096, 1683462, -1279041, 681348, -463786, 143378, -88651, 14644, -8366, 550, -297], 5728], [[-21488, -49248, -2551696, -183644, -5137492, -349602, -4061780, -353451, -1601412, -180164, -329596, -45697, -33084, -5348, -1228, -219], 5728], [[-21488, 49248, -2551696, 183644, -5137492, 349602, -4061780, 353451, -1601412, 180164, -329596, 45697, -33084, 5348, -1228, 219], 5728], [[-10720, 112616, -3666240, 1073600, -7173124, 1815660, -5519864, 1314659, -2131516, 490122, -432232, 97129, -42948, 9502, -1584, 347], 5728], [[10720, 112616, 3666240, 1073600, 7173124, 1815660, 5519864, 1314659, 2131516, 490122, 432232, 97129, 42948, 9502, 1584, 347], 5728], [[-13584, -75264, -3666240, -2983660, -7173124, -5726794, -5519864, -4390483, -2131516, -1693980, -432232, -343473, -42948, -34132, -1584, -1259], 5728], [[760, -181792, -3309340, -1366564, -6538530, -2377540, -5062604, -1827487, -1965886, -724606, -400736, -151637, -39998, -15494, -1480, -583], 2864], [[-11504, -174508, -5199540, -631426, -10001882, -856823, -7534298, -585517, -2843346, -218259, -563834, -44159, -54946, -4429, -1998, -165], 2864], [[-8640, 176252, -4091888, 1772034, -8074052, 3091787, -6251763, 2290282, -2425918, 866417, -493845, 173114, -49218, 17003, -1819, 622], 2864], [[-19968, 310848, -11385680, 268268, -22070212, -64450, -16752058, -108007, -6368040, -27268, -1271046, -333, -124536, 492, -4546, 33], 5728], [[7296, 44688, 3010036, -4070900, 5974346, -8110546, 4647313, -6284724, 1809584, -2436526, 369351, -495332, 36884, -49298, 1365, -1820], 2864], [[-25520, -305856, -13549384, 3397972, -26269624, 7237574, -19960958, 5627871, -7600708, 2158784, -1520034, 432565, -149204, 42456, -5454, 1551], 5728]]

hecke_ring_character_values = [[127, [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [1, 0, -1, 1, 0, 0, 0, -1, 1, 1, 1, 0, 0, 1, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 2, -1, 4, -3, 2, -2, 0, 3, 0, 0, 0, -2, 2, 0, -1], [4, -5, 5, -9, 7, -2, 1, -2, 4, 2, 1, -1, 1, 2, 1, 1], [0, 0, 2, 0, 5, -1, 8, 0, -2, -1, 6, -3, 5, 1, 2, -1], [0, 2, 1, -4, 3, 0, 1, 5, 0, -2, -6, 0, 0, -3, 4, 3], [7, 0, -2, 2, 5, 1, -1, -1, 3, 4, 2, -3, -6, 3, -4, -5], [16, -1, 9, 2, -2, 4, -1, -20, 11, 16, 3, -10, -5, 3, -6, 0], [13, -3, 9, -8, 3, -2, 8, -1, 1, 12, -3, -3, -6, 3, 4, 5], [5, 8, 5, -7, -4, -10, 6, -12, -10, 7, -7, 3, 5, -7, 3, 5], [-15, -9, -4, -9, 14, -6, -1, 2, -11, -17, 1, -1, -1, 6, 0, 4], [-19, 17, -16, 15, -28, 0, -6, 21, -17, -23, 2, 1, -2, 2, -5, 3], [1, 6, -13, 0, 2, 5, 1, -1, 7, -10, -5, -1, 5, 0, 1, 3], [14, -3, -7, 8, -22, 0, 5, 2, 8, 28, 6, -5, -2, 1, -2, 6], [-52, 12, -8, 19, -10, -18, 16, 28, -69, -35, -10, 9, 8, -16, 10, 10], [-23, -34, 9, -34, 0, -15, -10, -27, 23, -20, -11, 5, 4, 4, 0, -4], [19, 2, -10, 4, -12, -3, -5, -3, 23, -33, -1, 17, 3, 3, -1, -17], [18, 6, -19, 2, -1, -9, 5, -13, 11, 3, 14, 9, 0, 7, -15, -20], [14, -15, 6, -4, 21, 13, 0, 10, -21, 4, 14, -14, -17, -3, -29, -1], [18, -41, 27, -41, -11, -9, -3, -21, -6, 26, -8, 18, 9, -8, 9, 0], [56, -3, -2, -34, 3, 0, 8, -12, 27, 44, 6, 6, 26, -20, 4, -6], [-1, 0, 30, -1, 5, -1, 8, -2, 20, 0, 0, -3, -2, -7, -1, 9], [6, 21, 33, -40, -2, -29, 11, -15, -49, -24, -18, 17, 11, -29, 18, 17], [44, 34, -56, 21, -67, 0, -21, -32, 21, 62, -10, 3, -9, -2, -9, -10], [3, -29, -57, 68, 65, 6, -8, 4, 10, 14, 14, -11, 0, 3, -14, -14], [1, 45, -62, 45, -13, 28, -26, 20, 33, 26, 10, -14, -17, 25, -11, -10], [-23, -34, 66, -73, 72, -19, 36, 20, -66, -51, 4, -10, 19, -38, -10, 19], [-18, -22, -30, -22, 0, 14, 13, -31, 12, 15, 27, -16, 13, 13, 15, 2], [-54, 27, 29, -40, -36, -10, -4, 9, -56, -25, -24, 11, 9, -36, 20, 36], [-25, 1, 26, 1, -26, -7, 16, 56, -40, -32, 11, 0, 29, -7, 7, -4], [61, -84, 63, -33, 42, -6, -1, -45, -6, 30, -6, 0, -31, -7, -1, 37], [7, -29, 30, -23, -2, 26, 17, 4, -33, -19, -17, -9, -9, -8, 0, 26], [25, 52, -58, 89, 49, 58, -31, 22, 98, 69, 56, -51, -31, 58, -56, -51], [-24, -5, 5, 70, -40, -13, 11, 59, -14, -73, -2, -32, -27, 3, -29, 29], [-74, -61, 77, -38, 38, -39, 62, 29, -98, -69, -37, 25, 32, -44, 69, 69], [109, -54, 36, -5, 14, 29, -38, -20, 54, 31, -12, 12, -29, 26, 12, -13], [92, 13, -19, -41, 94, 16, -19, 13, 6, 96, 13, -21, -11, 36, -32, -36], [-1, -81, -20, -74, 35, 13, 9, -45, 85, 93, 6, -13, 0, 3, -6, -15], [-48, 32, -4, 119, -69, 28, -14, -40, 44, 40, -1, -4, -2, -1, 24, 0], [-35, 52, -40, 63, -52, 43, -52, 100, -6, 65, -29, -29, -49, 20, -26, -14], [52, -40, -7, -69, 20, -11, 29, -102, -11, 70, -13, -2, 16, 20, 31, -5], [-53, -48, 77, -106, 108, -18, 53, 30, -57, -22, -5, -52, 23, -23, -17, 40], [6, 17, 59, -67, 62, 11, 5, -73, 74, 69, 36, -5, 11, 0, 5, 7], [8, -49, -27, -45, 2, 0, -3, 45, -45, 21, -23, -19, 16, 4, 16, -23], [27, 42, -42, 66, -19, 55, -12, 27, 22, -5, 43, -4, -16, 31, 27, -27], [39, -37, 12, -36, 14, -21, -45, -21, 53, 4, -31, 17, -17, 21, -31, -17], [123, 68, -198, 120, -53, 30, -16, 45, 153, 115, 60, -70, -35, 60, -40, 0], [-27, 100, -69, 51, -78, 60, -35, 105, -32, 8, 36, 0, -6, -14, -60, -22], [35, 45, -4, 23, -45, -38, 26, -29, 32, 6, 55, 55, 38, 17, 13, -17], [-69, -30, 94, -99, 125, 3, 21, -32, -23, -102, 0, 9, 6, -97, 3, 18], [-23, -55, 80, -58, 12, -23, 35, 71, -155, -66, -49, 19, 35, -23, 49, 19], [119, 110, -112, 114, -78, 59, -79, -46, 160, 140, 14, -9, -73, 73, -29, -44], [-36, -9, -71, 40, 38, 35, 19, 103, -72, 31, 46, -14, 15, 17, -31, -31], [41, -38, 33, -36, 42, -23, -13, -25, 43, 18, 17, -21, 23, 26, -21, -13], [-66, -92, 139, -62, 11, -24, 58, 91, -47, -99, 10, 62, -14, -22, 48, 22], [2, 0, -7, 7, -217, -3, -6, -61, 119, 70, -13, 16, 34, -7, 10, 31], [8, 45, -25, -5, 71, -2, 0, 166, -84, -158, 8, -8, -54, -46, -41, -10], [-48, -129, 56, -160, 112, -13, 36, -53, 69, -47, 16, 0, -30, -30, 13, 14], [-101, -196, 86, -126, 98, -8, -42, 154, -8, -67, 12, 20, 54, -70, -62, -46], [-133, 93, -156, -40, -125, -10, -18, 151, -171, -30, 0, 4, 14, 51, 7, -25], [-187, -216, 40, -89, -96, -29, -20, 98, -292, -176, -45, 20, -29, 0, -20, 0], [146, -6, -174, 119, 47, 58, -71, -67, 128, 221, 49, -87, -58, 82, -87, -41], [-161, -55, 62, -90, 10, -12, -68, -12, -131, 37, -38, 0, -8, 12, -38, 0], [78, -44, 33, -11, 105, -8, 11, 17, 11, -16, -5, 6, 10, 6, 16, -6], [-48, 0, 187, 20, 40, -45, -23, 88, -244, -93, -28, 45, 0, -14, -32, -9], [-86, 62, -125, 105, -31, 84, -112, 153, 84, -93, 35, -49, -56, 21, -63, -28], [-87, 79, -66, 129, -21, -27, 19, 104, -25, -1, -19, 4, 4, 26, 0, 64], [138, 22, -115, 13, 66, 0, -44, -32, 13, 13, 13, -69, -67, 10, -67, 13], [31, -196, 196, -260, 297, -5, 33, -19, 0, 19, 28, -9, -15, 22, 13, -13], [93, 53, 165, -67, 20, -56, 3, 58, 1, -13, -11, 28, 47, -5, 9, 11], [67, 61, 261, 61, 0, 10, 77, 82, 52, -149, -5, -21, -15, -15, 88, 103], [68, 153, -43, 97, 18, 3, 85, 103, -32, -82, 12, -3, 0, 6, 95, 10], [-6, 38, -31, 234, 92, 79, 19, -22, 53, 94, 96, -128, -64, 96, -49, 0], [251, 176, -59, 218, -176, 23, -110, -289, 171, -38, -19, -19, -86, 67, -55, -4], [-211, 182, 58, -29, 110, -39, 63, -89, -30, 10, 0, -31, 8, -70, 4, 59], [-21, -137, 36, -95, -33, -50, 45, 76, -220, -62, -70, -1, 45, -50, 70, -1], [-110, -135, 87, 53, 19, 0, -42, 121, 53, -10, -37, 5, -19, 14, -19, -37], [64, 5, 183, -198, -6, -77, 161, -123, 34, -89, 60, 46, 149, -43, 89, 89], [42, 218, -66, 218, 0, -36, -5, -18, -46, 135, 24, 56, 60, 60, -25, -85], [-79, 0, -25, 25, 135, 28, 45, -69, 166, 333, 69, -97, -19, 24, -52, 9], [1, 75, 32, -19, 115, -30, 0, 123, 12, -122, 1, -1, 78, 79, 23, -31], [168, -24, 258, 296, 12, 31, -2, -59, 31, 135, -13, -44, -77, 73, 42, 46], [55, -113, 124, -58, 32, -70, 82, 50, -28, 12, 0, -94, -24, 40, -12, 94], [-211, -14, -138, 193, -83, 111, -82, 179, 264, -18, 39, -16, -82, 111, -39, -16], [157, 238, -310, 97, -144, 81, 44, -60, 50, 9, 116, -44, 81, 0, 44, -81], [57, 249, -249, 268, -39, 88, 45, 144, -4, -148, 133, -96, -129, 100, 4, -4], [-211, 91, 117, -31, -175, -24, 172, 98, -48, -256, 20, 36, 24, -96, 36, 48], [-107, -138, 189, -221, 51, -35, 94, -35, -164, 68, 37, 73, -20, 35, 37, -73], [165, -21, -19, 167, 182, 47, -119, 75, 40, -159, -25, -36, -58, -11, -94, 11], [-236, 67, -55, 317, -127, -7, -4, 176, -200, -310, 14, 7, 0, 7, 44, 48], [168, -187, -162, 100, 187, 92, -216, -32, 173, 136, -38, -38, -102, 64, -108, -54], [188, -219, 267, -75, 22, 42, 67, -133, -86, 120, -67, -77, -77, -62, 0, 72], [65, 208, -89, -30, -294, 42, -79, -123, -9, -46, -100, 126, 58, -58, 89, -31], [121, -165, 165, -90, 204, -52, 102, -177, -78, 99, 50, -64, -93, 21, -43, 43], [187, -99, 58, 213, 56, 28, 13, -160, -63, 131, 40, -14, -62, 61, 34, -40], [27, 31, -134, 31, 0, 67, -9, 43, -35, 79, 51, 22, -16, -16, -98, -82], [-137, -125, -25, -118, -163, -99, 0, 18, 59, -155, -137, 137, 24, -113, -25, 38], [10, 64, 226, -182, -208, -112, 16, -229, 3, -173, -63, 254, 127, -63, 142, 0], [-323, -306, 360, -414, 312, -133, 121, 119, -226, -238, -71, 31, 204, -204, 19, 185], [-146, -301, 171, -180, 191, 0, -84, 266, -180, -73, -10, -83, -109, 35, -109, -10], [-455, 151, 21, -79, -109, -96, 86, 134, -260, -276, -66, 10, 96, -208, 10, 104], [-227, -137, 11, -251, -259, 8, -163, 27, 126, 197, -147, 43, -59, -43, -16, 43], [186, 0, -8, 8, -218, 48, -84, -15, 78, -112, -113, 65, -109, -29, -19, -61], [-74, 257, 166, -38, 185, 85, 0, 27, -39, -101, -74, 74, -48, -122, 79, 159], [125, 252, -435, 96, 29, 105, -61, -184, 221, 368, 175, 0, 84, 87, -105, -262], [269, 419, -119, 287, -142, 39, -141, -163, 582, 303, 141, 36, 36, 147, 0, -135], [-67, -62, -45, -30, -74, 5, -167, 37, 31, -85, -112, 167, 5, 0, -167, -22], [69, -118, 118, -222, 18, 71, -62, -162, 8, 170, 9, 213, 41, -163, 50, -50], [-15, 38, -96, -60, -129, 93, -16, 351, -284, 67, 25, -40, -42, 27, -67, -67], [-130, -171, 304, -662, 162, -147, 154, 344, -195, -210, -25, 50, 147, -154, 50, 77], [57, -46, 146, -414, 75, -134, 230, -122, -100, 64, -38, 128, 140, -204, 268, 204], [-49, -258, 286, -135, 323, -16, 30, 114, -149, 193, 74, 16, 0, 37, -42, -72], [120, 0, -372, 372, -23, -73, -77, 114, -301, -307, 133, -60, 19, 210, -137, -54], [-146, 52, -194, -96, -26, 23, -118, -57, 23, -17, -29, -52, 77, -43, -66, -100], [24, 90, -142, 194, 134, 137, -114, 185, -168, -145, 72, -11, -209, 209, 12, -221], [-125, -85, -103, 273, -23, 40, -110, 398, 2, -90, 22, 110, 40, 0, -110, -98], [51, 95, -150, 57, 184, 0, 5, -26, 57, -351, -30, 98, 104, -69, 104, -30], [86, 346, -84, 9, 131, 46, -63, 292, 145, 208, 70, -23, 33, 54, -79, -70], [-38, 35, -215, 35, 0, -28, -10, -170, 156, 90, 104, -47, 132, 132, 65, -67], [338, 172, -89, 521, -283, -53, 88, -53, 232, -6, -18, 10, -124, 53, -18, -10], [-263, -170, 123, 84, 281, 33, 21, 110, -233, -30, 21, -60, -30, 21, -27, 0], [81, 3, -145, 69, 12, 29, 65, -39, -58, -84, 89, 0, -99, -99, -29, 10], [-92, 214, -497, 122, -263, 14, -54, -59, -221, 108, 0, 214, 200, -107, 100, -154], [227, -3, -183, 369, -114, 166, -289, -101, 610, 487, -40, 65, -126, 126, -58, -68], [-156, 329, 169, 286, 121, 147, -58, -78, 158, 80, -45, -40, -125, 40, -80, -80], [-249, -1, 364, -1, 0, 94, -76, -174, -207, 227, 19, -71, -75, -75, -99, -24], [-445, 0, 139, -139, 120, -96, 138, 216, -528, -299, -23, 119, 193, -161, 257, 97], [296, 231, -194, 463, -167, 3, -44, -54, -112, 116, -30, 0, 27, 52, -3, -22], [231, -855, 780, -624, 744, -66, 64, -188, 126, -558, 0, 2, 68, -46, 34, 30], [-546, 206, 496, -311, 309, -182, 129, 508, -432, -373, -159, 28, 129, -182, 159, 28], [-22, -45, -279, 395, -56, -23, 27, 417, -128, -427, -6, -27, -23, 0, 27, 103], [114, -231, -101, -216, 30, 81, 219, 425, -490, -65, 8, -108, 73, -173, 65, 65], [-44, 327, -51, 19, 96, 27, -85, 335, -136, -148, 101, -31, -27, 256, -31, -128], [414, 195, -232, 369, -51, -82, -53, -82, 492, 324, 25, -82, 103, 82, 25, 82], [383, 0, -114, 114, 123, 158, 124, 66, 26, -76, 143, -301, -138, 19, -177, 20], [342, 418, -275, 104, -34, 73, -129, -30, 305, -40, 68, -276, -138, 68, -203, 0], [-374, 296, -302, 401, 113, 95, 23, 348, -52, -34, -23, -87, -87, 87, 0, 133], [574, 390, -546, 613, -364, 0, 18, -386, 613, 341, 32, 19, -10, -4, -10, 32], [-197, -388, 182, -388, 0, -92, -30, -129, 66, -264, -160, 114, -68, -68, -52, 16], [-275, 106, -194, -29, -217, 56, -325, 56, -20, -7, -70, 129, 185, -56, -70, -129], [-128, -588, 280, -228, -388, -49, 0, -147, -237, 19, -128, 128, -17, -145, 1, 79], [83, 107, 27, 318, -95, 245, -67, -158, 131, 269, 25, -256, -128, 25, -11, 0], [472, 451, -328, 723, -251, 115, -198, -62, -70, 266, -100, 0, -293, 66, -115, 34], [491, 133, -204, -243, -133, 217, -348, -114, 326, 377, -187, -187, -358, 171, -174, -30], [326, 163, 85, 433, 91, 209, -224, -289, 404, 247, 8, 2, -224, 209, -8, 2], [-331, 84, -176, -259, -359, 48, -37, 181, 113, -432, -106, -24, -20, -97, -28, 106], [-225, 216, -37, 222, -78, 57, -105, 51, -315, -212, -141, 111, -57, -66, 111, 33], [-450, -70, -271, -70, 0, -37, -205, -263, -95, -111, -224, 45, -187, -187, -213, -26], [-354, -359, 280, -248, 40, -13, 180, 254, 79, 47, 154, -114, 140, 79, 26, -79], [-323, 233, -121, -17, -306, -64, 19, -95, -496, -199, -216, 0, -98, -126, 64, 342], [301, -230, -432, -450, 115, 106, -128, -180, 106, 458, 43, -63, 94, 41, -65, -200], [-130, -488, 79, -618, 40, -151, 66, 334, -483, -467, 0, 93, 244, -12, 122, -56], [327, -86, 616, -367, 459, 78, -17, -650, 564, 117, 17, -136, -136, 166, 0, 132], [-32, 123, 93, 227, -4, 135, -5, 31, 68, -238, 91, -231, -135, -44, -231, 22], [723, -205, 103, -163, 149, -47, -70, -47, 658, 239, -135, 23, -200, 47, -135, -23], [-277, 0, 12, -12, 297, 127, 71, 385, -643, -634, -194, 67, 74, -265, 138, 201], [-898, 116, 43, 219, -116, -61, 168, 578, -482, -320, 102, 102, 268, -166, 84, -41], [242, -168, -167, -169, -8, 119, -209, -251, 83, -46, 209, 17, 17, 128, 0, -290], [-438, 61, 64, -189, 276, 225, -80, 512, -401, -256, -151, -100, -74, 74, 45, -119], [-66, -282, -56, -280, 343, 0, -287, 281, -280, -457, -123, 115, -165, 1, -165, -123], [119, 351, -689, 367, -302, 292, -237, 36, 555, 159, 201, -146, -169, 315, -123, -201], [-158, -310, 1, -394, -191, -207, -183, -343, 305, -55, -242, 207, 0, -121, -29, 154], [32, -45, -309, 109, -199, -122, 0, -393, 336, 425, 32, -32, 31, 63, -1, -154], [46, -457, 660, -512, 558, -217, 196, -209, 289, 49, -94, 0, 162, -52, 217, 146], [-189, 465, -164, 276, 288, -1, -50, -442, 101, 277, 0, -123, -122, 284, -61, 11], [-47, -144, -289, 722, -610, -54, -7, 31, 153, 92, 38, 98, 16, -16, 37, -21], [355, 403, -387, 499, -843, 0, -74, -502, 499, 656, -131, 286, -42, 99, -42, -131]]
